@@ -1,37 +1,37 @@
 fclustIndex <- function ( y, x, index= "all" )
 {
 
-  clres <- y  
+  clres <- y
 ###########################################################################
 ################SESSION 1: MEASURES#########################################
 ###########################################################################
-  
+
   gath.geva <- function (clres,x)#for m=2
     {
       xrows <- dim(clres$me)[1]
       xcols <- dim(clres$ce)[2]
       ncenters <- dim(clres$centers)[1]
-      scatter <- array(0.0, c(xcols, xcols, ncenters))   
+      scatter <- array(0.0, c(xcols, xcols, ncenters))
       scatternew <- array(0.0, c(xcols, xcols, ncenters))
       fhv <-as.double(0)
       apd <-as.double(0)
       pd <-  as.double(0)
       control <- as.double(0)
-      
+
       for (i in 1:ncenters){
         paronomastis <- as.double(0)
         paronomastis2 <- as.double(0)
-        
+
         for (j in 1:xrows){
           paronomastis <- paronomastis+clres$me[j,i]
-          
+
           diff <- x[j,]-clres$ce[i,]
           scatternew[,,i] <- clres$me[j,i]*(t(t(diff))%*%t(diff))
           scatter[,,i] <- scatter[,,i]+scatternew[,,i]
         }#xrows
         scatter[,,i] <- scatter[,,i]/paronomastis
-        
-    
+
+
         for (j in 1:xrows){
           diff <- x[j,]-clres$ce[i,]
           control <- (t(diff)%*%solve(scatter[,,i]))%*%t(t(diff))
@@ -41,24 +41,24 @@ fclustIndex <- function ( y, x, index= "all" )
           ##     cat("...")
         }#xrows
         fhv <- fhv+sqrt(det(scatter[,,i]))
-        
+
         apd <- apd+paronomastis2/sqrt(det(scatter[,,i]))
-        
+
         pd <- pd+paronomastis2
-        
+
       }#ncenters
       pd <- pd/fhv
       apd <- apd/ncenters
-      
+
       retval <- list(fuzzy.hypervolume=fhv,average.partition.density=apd, partition.density=pd)
       return(retval)
     }
-  
+
   xie.beni <- function(clres){#for all m
     xrows <- dim(clres$me)[1]
     minimum<--1
     error <- clres$within#sd
-    ncenters <- dim(clres$centers)[1] 
+    ncenters <- dim(clres$centers)[1]
     for (i in 1:(ncenters-1)){
       for (j in (i+1):ncenters){
         diff<- clres$ce[i,]-clres$ce[j,]
@@ -71,36 +71,36 @@ fclustIndex <- function ( y, x, index= "all" )
     xiebeni <- error/(xrows*minimum)
     return(xiebeni)
   }
-  
+
   fukuyama.sugeno <- function(clres){#for all m
     xrows <- dim(clres$me)[1]
     ncenters <-dim(clres$centers)[1]
     error <- clres$within#sd
     k2<-as.double(0)
-    
+
     meancenters <- apply(clres$ce,2,mean)
     for (i in 1:ncenters){
-      paronomastis3 <- as.double(0)  
+      paronomastis3 <- as.double(0)
       for (j in 1:xrows){
         paronomastis3 <- paronomastis3+(clres$me[j,i]^2)}
-      
+
       diff <- clres$ce[i,]-meancenters
       diffdist <- t(diff)%*%t(t(diff))
       k2 <- k2 +paronomastis3*diffdist
     }#ncenters
-    
+
     fukuyamasugeno<-error-k2
     return(fukuyamasugeno)
   }
-  
+
   partition.coefficient <- function(clres){
     xrows <- dim(clres$me)[1]
-    
+
     partitioncoefficient <- sum(apply(clres$me^2,1,sum))/xrows
     return(partitioncoefficient)
   }
-  
-  partition.entropy <- function(clres){ 
+
+  partition.entropy <- function(clres){
     xrows <- dim(clres$me)[1]
     ncenters <- dim(clres$centers)[1]
     partitionentropy <- 0.0
@@ -113,7 +113,7 @@ fclustIndex <- function ( y, x, index= "all" )
     ##partitionentropy <- sum(apply(clres$me*log(clres$me),1,sum))/((-1)*xrows)
     return(partitionentropy)
   }
-  
+
   separation.index <- function(clres, x)
     {
       xrows <- dim(clres$me)[1]
@@ -122,7 +122,7 @@ fclustIndex <- function ( y, x, index= "all" )
       maxcluster <- double(ncenters)
       minimum <- -1.0
       ##hardpartition <- matrix(0,xrows,ncenters)
-      
+
       ##for (i in 1:xrows)
       ## hardpartition[i,clres$cl[i]] <- 1
       for (i in 1:ncenters){
@@ -145,13 +145,13 @@ fclustIndex <- function ( y, x, index= "all" )
                 }}}}}}
       return(minimum)
     }
-  
+
 
   proportion.exponent <- function(clres)
     {
       k <- dim(clres$centers)[2]
       xrows <- dim(clres$me)[1]
-      
+
       bexp <- as.integer(1)
       for (j in 1:xrows){
         greatint <- as.integer(1/max(clres$me[j,]))
@@ -164,26 +164,26 @@ fclustIndex <- function ( y, x, index= "all" )
           ##}
         }
         bexp <- bexp * aexp
-        
+
       }
       proportionexponent <- -log(bexp)
       return(proportionexponent)
     }
-  
+
 ###########################################################################
 ################SESSION 2: MAIN PROGRAM####################################
-###########################################################################  
+###########################################################################
 
   index <- pmatch(index, c("gath.geva", "xie.beni", "fukuyama.sugeno",
                            "partition.coefficient", "partition.entropy",
                            "proportion.exponent", "separation.index", "all"))
-  
-  
-  if (is.na(index)) 
+
+
+  if (is.na(index))
     stop("invalid clustering index")
-  if (index == -1) 
+  if (index == -1)
     stop("ambiguous index")
-  
+
    vecallindex <- numeric(9)
 
   if (any(index==1) || (index==8)){
@@ -203,14 +203,18 @@ fclustIndex <- function ( y, x, index= "all" )
     vecallindex[8] <- proportion.exponent(clres)
   if (any(index==7) || (index==8))
       vecallindex[9] <- separation.index(clres,x)
-  
+
   names(vecallindex) <- c("fhv", "apd", "pd", "xb", "fs", "pc", "pe",
                           "pre", "si")
-  
 
-  if (index < 8)
-    vecallindex <- vecallindex[index]
-  
+
+  if (index < 8) {
+      if (index == 1)
+          vecallindex <- vecallindex[1:3]
+      else
+          vecallindex <- vecallindex[index + 2]
+  }
+
   return(vecallindex)
 }
 
